[m-rev.] for review: fix store_at_ref_type spelling

Peter Wang novalazy at gmail.com
Thu Jan 17 18:38:41 AEDT 2008


Estimated hours taken: 0.5
Branches: main

compiler/lco.m:
compiler/mlds.m:
	Replace occurrences of "store_by_ref_type" by "store_at_ref_type",
	which is the name used in private_builtin.m.

Index: compiler/mlds.m
===================================================================
RCS file: /home/mercury/mercury1/repository/mercury/compiler/mlds.m,v
retrieving revision 1.161
diff -u -r1.161 mlds.m
--- compiler/mlds.m	31 Dec 2007 10:03:49 -0000	1.161
+++ compiler/mlds.m	17 Jan 2008 05:05:39 -0000
@@ -1819,7 +1819,7 @@
     ;
         type_to_ctor_and_args(Type, TypeCtor, [RefType]),
         TypeCtor = type_ctor(qualified(mercury_private_builtin_module,
-            "store_by_ref_type"), 1)
+            "store_at_ref_type"), 1)
     ->
         MLDSRefType = mercury_type_to_mlds_type(ModuleInfo, RefType),
         MLDSType = mlds_ptr_type(MLDSRefType)

--------------------------------------------------------------------------
mercury-reviews mailing list
Post messages to:       mercury-reviews at csse.unimelb.edu.au
Administrative Queries: owner-mercury-reviews at csse.unimelb.edu.au
Subscriptions:          mercury-reviews-request at csse.unimelb.edu.au
--------------------------------------------------------------------------



More information about the reviews mailing list
Index: compiler/lco.m
===================================================================
RCS file: /home/mercury/mercury1/repository/mercury/compiler/lco.m,v
retrieving revision 1.50
diff -u -r1.50 lco.m
--- compiler/lco.m	14 Jan 2008 04:45:06 -0000	1.50
+++ compiler/lco.m	17 Jan 2008 05:05:39 -0000
@@ -48,7 +48,7 @@
 %       app'(T, B, AddrHT)
 %   )
 %
-% app'(list(T)::in, list(T)::in, store_by_ref_type(T)::in)
+% app'(list(T)::in, list(T)::in, store_at_ref_type(T)::in)
 % app'(A, B, AddrC) :-
 %   (
 %       A == [],
@@ -77,7 +77,7 @@
 % transformation
 %
 % 3 replaces the output arguments with input arguments of type
 %   store_by_ref_type(T), where T is type of the field pointed to, and
 %
 % 4 follows each primitive goal that binds one of the output arguments
 %   with a store to the memory location indicated by the corresponding pointer.
@@ -646,7 +646,7 @@
 
 make_ref_type(FieldType) = PtrType :-
     RefTypeName = qualified(mercury_private_builtin_module,
-        "store_by_ref_type"),
+        "store_at_ref_type"),
     PtrType = defined_type(RefTypeName, [FieldType], kind_star).
 
 %-----------------------------------------------------------------------------%
@@ -77,7 +77,7 @@
 %
 % 3 replaces the output arguments with input arguments of type
-%   store_by_ref_type(T), where T is type of the field pointed to, and
+%   store_at_ref_type(T), where T is type of the field pointed to, and
 %
 % 4 follows each primitive goal that binds one of the output arguments